| fvYearlyCompSingleCF | R Documentation |
Computing Future Value of a Single Cash Flow with Yearly Compounding Frequency.
fvYearlyCompSingleCF(r, n, pv)
r |
A number. |
n |
A number. |
pv |
A number. |
As \insertCitebrook;textualtvmComp explains Future Value is the cash value of an money or an asset in the future that is equivalent in value to a specific amount today. This, acts as basis of understanding how interest accumulates (and gets compounded) and how the Time Value of Money equation can be used for estimating growth. On these lines, fvYearlyCompSingleCF() was developed and it calculates Future Value of a Single Cash Flow with Yearly Compounding Frequency.
fvYearlyCompSingleCF() gives Future Value when values are passed to its three arguments. Here r is annual rate, n is number of years and pv is Present Value
Input values to three arguments r , n and pv.
MaheshP Kumar, maheshparamjitkumar@gmail.com
brooktvmComp
fvYearlyCompSingleCF(0.08,10,2000) fvYearlyCompSingleCF(0.08,10,-2000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.