| pvSemiAnnualCompSingleCF | R Documentation |
Computing Present Value of a Single Cash Flow for Semi-Annual Compounding.
pvSemiAnnualCompSingleCF(r, n, fv)
r |
A number. |
n |
A number. |
fv |
A number. |
The method pvSemiAnnualCompSingleCF() is developed to compute Present Value of a Single Cash Flow for Semi-Annual Compounding Frequency and gives Present Value when values are passed to its three arguments. Here r is annual rate, n is number of years and fv is Future Value.
Input values to three arguments r , n and fv.
MaheshP Kumar, maheshparamjitkumar@gmail.com
hummtvmComp
pvSemiAnnualCompSingleCF(0.08,10,2000) pvSemiAnnualCompSingleCF(0.08,10,-2000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.