| pvSemiAnnuallyPaidAnnuityCompSemiAnnually | R Documentation |
Computing Present Value of Semi-Annually Paid Ordinary Annuity or Annuity Due that is Compounded Semi-Annually.
pvSemiAnnuallyPaidAnnuityCompSemiAnnually(r, n, pmt, bgn)
r |
A number. |
n |
A number. |
pmt |
A number. |
bgn |
A number. |
The method pvSemiAnnuallyPaidAnnuityCompSemiAnnually() is developed to compute Present Value of Semi-Annually Paid Ordinary Annuity or Annuity Due that is Compounded Semi-Annually and gives Present Value when values are passed to its four arguments. Here r is annual rate, n is number of years, pmt is amount of one annuity and bgn is the computational mode. (Enter 1 when annuity payment occurs at the beginning of the period; 0 for end of period payments)
Input values to four arguments r , n , pmt and bgn
MaheshP Kumar, maheshparamjitkumar@gmail.com
hummtvmComp
pvSemiAnnuallyPaidAnnuityCompSemiAnnually(0.06,12, -200, 1) pvSemiAnnuallyPaidAnnuityCompSemiAnnually(0.06,12, -200, 0) pvSemiAnnuallyPaidAnnuityCompSemiAnnually(0.06,12, 200, 1) pvSemiAnnuallyPaidAnnuityCompSemiAnnually(0.06,12, 200, 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.