| rorPerpetuity | R Documentation |
Computing Rate of Return of a Perpetuity.
rorPerpetuity(yearendCF, deposit)
yearendCF |
A number. |
deposit |
A number. |
As defined by \insertCitehumm;textualtvmComp, a Perpetuity is an annuity in which the periodic payments begin on a fixed date and continue indefinitely. Interest payments on permanently invested sums of money are prime examples of Perpetuity. Dividends on preferred shares fall into this category if the issuing corporation has an indefinite life. Scholarships and trust funds paid perpetually from an endowment also fit the definition of Perpetuity.
The method rorPerpetuity() is developed to compute Rate of Return(r) of a Perpetuity and gives r when values are passed to its two arguments. Here yearendCF is Cash Flow occurring at the Year-End and deposit stands for amount of the Deposit
Input values to two arguments yearendCF and deposit
MaheshP Kumar, maheshparamjitkumar@gmail.com
hummtvmComp
rorPerpetuity(15, 180) rorPerpetuity(10, 120)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.